---
--- Generated by EmmyLua(https://github.com/EmmyLua)
--- Created by brode.
--- DateTime: 11.06.2021 16:10
---


local AddonName, BohemkaDKP = ...

BohemkaDKP.frames = {}
BohemkaDKP.roster = {}
BohemkaDKP.rosterCache = {}
BohemkaDKP.rosterIndex = {}
BohemkaDKP.sortedRoster = {}
BohemkaDKP.guildRoster = {}
BohemkaDKP.bidInfo = {}
BohemkaDKP.bidHistory = {}
BohemkaDKP.rosterProfessions = {}
BohemkaDKP.rosterTalents = {}
BohemkaDKP.editModeSelected = {}
BohemkaDKP.passedHistory = {}
BohemkaDKP.conflicts = {}
BohemkaDKP.currentItem = nil



function BohemkaDKP:OnLoad()
    self:CheckCompatibility()
    self:UpdateCompatibility()
    self:HookScripts()
    self:HookLootFrame()
    GuildRoster();
    --self:LoadDKPRoster()
    --self:CacheGuildRoster()
    self:LoadUI()
    self:ShareProfessions()
    self:JoinExistingAuction()
    self:ShareTalents()
end

function BohemkaDKP:ShareTalents()
    local numTabs = GetNumTalentTabs();
    local tabs = {}
    for t=1, numTabs do
        local name, _, pointsSpent = GetTalentTabInfo(t)
        table.insert(tabs, name:gsub("%s+", "").."-"..pointsSpent)
    end
    local payload = table.concat(tabs, ",")
    self:SendEvent("GUILD", self.EVENT.TALENTS_INFO, payload)
end

function BohemkaDKP:ShareProfessions()
    local skills = {}
    local skillRanks = {}
    for skillIndex = 1, GetNumSkillLines() do
        local skillName, isHeader, _, skillRank, _, _,
        _, _, _, _, _, _,
        _ = GetSkillLineInfo(skillIndex)
        if not isHeader then
            if BohemkaDKP.PROFESSIONS[skillName] then
                skillRanks[skillName] = skillRank
            end
        end
    end
    local _, _, offset, numSlots = GetSpellTabInfo(1)
    for j = offset+1, offset+numSlots do
        local name, _, _, _, _, _, spellId = GetSpellInfo(GetSpellBookItemName(j, BOOKTYPE_SPELL))
        if BohemkaDKP.PROFESSIONS[name] then
            local data = spellId
            if name == "Find Herbs" then
                data = 9134
                name = "Herbalism"
            end
            if skillRanks[name] then
                data = data.."-"..skillRanks[name]
            end
            table.insert(skills, data)
        end
    end
    local payload = table.concat(skills, ",")
    self:SendEvent("GUILD", self.EVENT.PROFESSION_INFO, payload)
end

function BohemkaDKP:OnProfessionInfo(payload, sender)
    local spellIds = { strsplit(",", payload) }
    if sender then
        self.rosterProfessions[sender] = spellIds
    end
end

function BohemkaDKP:OnTalentsInfo(payload, sender)
    local talents = { strsplit(",", payload) }
    if sender then
        self.rosterTalents[sender] = talents
    end
end

function BohemkaDKP:LoadUI()
    self:AddStaticPopups()
    self:CreateInterfaceConfig()
    self:CreateAuctionFrame()
    self:AdjustUI()
end



function BohemkaDKP:OnUpdateCompatibilityCallback()

end

function BohemkaDKP:OnUiAdjustedCompatibilityCallback()

end

function BohemkaDKP:CheckCompatibility()
    name, title, notes, loadable, reason, security, newVersion = GetAddOnInfo("ElvUI")
    self.isElvUI = loadable
end

function BohemkaDKP:LoadDKPRoster()
    local totalMembers, _, _ = GetNumGuildMembers();
    local canEdit = CanEditPublicNote()
    local canEditOfficer = CanEditOfficerNote()
    for i = 1, totalMembers do
        fullName, rank, rankIndex, level, class, zone, note, officernote, online, isAway = GetGuildRosterInfo(i);
        local currentDKP = self:NoteDKPToNumber(note)
        if currentDKP == nil and canEdit then
            currentDKP = BohemkaDKPConfig.startingDKP
            if canEditOfficer and note ~= nil and note ~= "" then
                GuildRosterSetOfficerNote(i, note)
            end
            self:SaveDKP(i, currentDKP)
        end
        self.roster[fullName] = currentDKP
    end
end


function BohemkaDKP:GetCurrentGuildButtonFrameNamePrefix()
    if FriendsFrame.playerStatusFrame then
        return "GuildFrameButton"
    else
        return "GuildFrameGuildStatusButton"
    end
end

function BohemkaDKP:CacheGuildRoster()
    self.guildRoster = {}
    self.rosterCache = {}
    local n = 0
    local totalMembers, _, _ = GetNumGuildMembers();
    for i = 0, totalMembers do
        fullName, rank, rankIndex, level, class, zone, note, officernote, online, isAway, classFileName = GetGuildRosterInfo(i);
        if fullName then
            self.guildRoster[fullName] = { fullName, rank, rankIndex, level, class, zone, note, officernote, online, isAway, classFileName }
            self.rosterIndex[fullName] = i
            n = n + 1
        end
    end
    print("CACHED", n)
end

function BohemkaDKP:StartAuction(itemLink, quantity, itemFrame)
    if CanEditPublicNote() and not self.currentItem then
        local itemId = select(2, strsplit(":", itemLink, 3))
        local itemName = GetItemInfo(itemId)
        local auctionId = math.random()
        BohemkaDKP:SendEvent(BohemkaDKP:GetBroadcastChannel(), BohemkaDKP.EVENT.START_AUCTION, self:GetPlayerName(true), itemId, quantity, BohemkaDKP:GetItemMinPrice(itemName), auctionId, BohemkaDKPConfig.minBid)
        SendChatMessage(format("Auction for %s has started. Price: %d DKP.", itemLink, BohemkaDKP:GetItemMinPrice(itemName)), BohemkaDKP:GetBroadcastChannel())
        if self.lastItemFrame then
            ActionButton_HideOverlayGlow(self.lastItemFrame);
        end
        ActionButton_ShowOverlayGlow(itemFrame)
        self.lastItemFrame = itemFrame
        self.frames.auction.lootMasterFrame:Show()
        self:UpdateBidderTable()
        self.passedHistory = {}
    end
end

function BohemkaDKP:OnStartAuction(owner, itemId, quantity, price, auctionId, minBid)
    self:Debug("Started auction", owner, itemId, quantity, price, auctionId)
    self.currentItem = {
        id = tonumber(itemId),
        owner = owner,
        quantity = quantity,
        price = price,
        auctionId = auctionId,
        minBid = tonumber(minBid),
        initPrice = price,
    }
    local itemName, _, itemRarity, _, _, _, _, _, _, itemTexture, _ = GetItemInfo(self.currentItem.id)
    if not itemName then
        self.waitForItemInfo = true
        return
    else
        self:LoadAuctionData(itemId, quantity, price, itemName, itemRarity, itemTexture)
    end
    self:OnBidCooldownEnd(auctionId)
    self:UpdateWinner()
end

function BohemkaDKP:LoadAuctionData(_, quantity, price, itemName, itemRarity, itemTexture)
    local color = ITEM_QUALITY_COLORS[itemRarity];

    local buttonName = "AuctionFrameItem"
    local text = getglobal(buttonName.."Text")
    local buttonTexture = getglobal(buttonName.."IconTexture")
    local count = getglobal(buttonName.."Count")
    local priceValue = getglobal("AuctionItemPriceValue")
    self:RefreshTotalDKP()
    priceValue:SetText(price)
    buttonTexture:SetTexture(itemTexture)
    count:SetText(quantity)
    if tonumber(quantity) > 1 then
        count:Show()
    else
        count:Hide()
    end
    local bidValue = getglobal("BidValue")
    bidValue:SetText("0")
    text:SetVertexColor(color.r, color.g, color.b)
    text:SetText(itemName)
    self.currentTime = BohemkaDKPConfig.timerMax
    self.passed = false
    self:EnableBidding(true)
    self:SetHighestBidder(nil)
    self.bidInfo = {}
    self.frames.auction:Show()
    if self:IsPlayerAuctionOwner() then
        AuctionDKPClose:Hide()
    else
        AuctionDKPClose:Show()
    end
    self.currentItem.price = tonumber(price)
end


function BohemkaDKP:OnBid(value, sender, auctionId)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self:Debug("Bid accepted from", sender, value)
    _G["AuctionItemPriceValue"]:SetText(value)
    value = tonumber(value)
    self:SetHighestBidder(sender, value)
    self:SetCurrentDKPValue(self:GetCurrentDKP() - value)
    local bidValue = getglobal("BidValue")
    if not bidValue.isChanged then
        bidValue:SetText(self.currentItem.minBid)
    end

    if sender == self:GetPlayerName(true) and self:GetCurrentDKP() == value then
        self.currentItem.allIn = true
    end
    self:UpdatePassButtonState()
end


function BohemkaDKP:Bid(amount)
    if not self.isBiddingEnabled or amount == nil or (self.bidInfo.name and (not amount or amount == 0)) then
        return
    end
    if amount > 0 and amount < self.currentItem.minBid then
        return
    end
    BohemkaDKP:SendEvent(BohemkaDKP:GetBroadcastChannel(), BohemkaDKP.EVENT.BID_REQUEST, amount,  self.currentItem.auctionId)
    BohemkaDKP:Debug("Bidding", amount)
    self:EnableBidding(false)
end

function BohemkaDKP:Pass()
    if self.passed then
        return
    end
    self.passed = true
    BohemkaDKP:SendEvent(BohemkaDKP:GetBroadcastChannel(), BohemkaDKP.EVENT.PASS_REQUEST, self.currentItem.auctionId)
    BohemkaDKP:Debug("Passing")
    self:EnableBidding(false)
    self.frames.auction.pass:Disable()
end

function BohemkaDKP:OnPassRequest(auctionId, sender)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self:Debug("Pass request from", sender, amount, "I am auction owner:", self:IsPlayerAuctionOwner())
    if not self:IsPlayerAuctionOwner() then
        self:Debug("Skipping because I am not loot master")
        return
    end
    if self.bidHistory[sender] == self.currentItem.price then
        self:Debug("Request ignored.", sender, "is the highest bidder.")
        return
    end
    self.bidHistory[sender] = nil
    self.passedHistory[sender] = true
    self:ValidateBidderDKP()
end



function BohemkaDKP:OnBidRequest(amount, auctionId, sender)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self:Debug("Bid request from", sender, amount, "I am auction owner:", self:IsPlayerAuctionOwner())
    amount = tonumber(amount)
    -- amount = BohemkaDKP:roundWhole(amount, 10)
    amount = amount - amount % self.currentItem.minBid
    if not self:IsPlayerAuctionOwner() or self.isBidOnCooldown then
        self:Debug("Skipping because I am not loot master")
        return
    end
    if self.bidInfo.name and amount < BohemkaDKPConfig.minBid then
        return
    end
    if self.bidInfo.name == sender then
        self:Debug("Ignored because request comes from highest bidder")
        return
    end
    if self.passedHistory[sender] then
        self:Debug("Ignored because request comes from someone who passed")
        return
    end
    local price = tonumber(_G["AuctionItemPriceValue"]:GetText())
    local newBid = price + amount
    local senderCurrentDKP = self:GetCurrentDKP(sender)
    self:Debug("Checking his current DKP", senderCurrentDKP)
    newBid = math.min(senderCurrentDKP, newBid)
    if self.bidInfo.name and (newBid <= self.bidInfo.value and (newBid ~= self.bidInfo.value or senderCurrentDKP ~= newBid)) then
        self:Debug("Ignored because value is too low", newBid , "<=", self.bidInfo.value)
        return
    end

    if newBid < self.currentItem.minBid then
        return
    end

    if self.bidHistory[sender] and self.bidHistory[sender] == senderCurrentDKP then
        return
    end

    self.currentItem.price = newBid
    self.isBidOnCooldown = true
    C_Timer.After(BohemkaDKPConfig.bidCooldown, function ()
        self.isBidOnCooldown = false
        self:SendEvent(BohemkaDKP:GetBroadcastChannel(), self.EVENT.BID_COOLDOWN_END, auctionId)
    end)
    if self.countdownActive then
        self:CancelAuctionCountdown()
    end
    self:SendEvent(BohemkaDKP:GetBroadcastChannel(), self.EVENT.BID, newBid, sender, self.currentItem.auctionId)
    self.bidHistory[sender] = newBid
    self:UpdateBidderTable()
end

function BohemkaDKP:OnBidCooldownEnd(auctionId)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self:UpdateBidButtonState()
end


function BohemkaDKP:EndAuction(force)
    if not self.currentItem or not self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    if not force and IsShiftKeyDown() then
        self.countdownActive = true
        self.frames.auction.lootMasterFrame.award:Disable()
        self:SendEvent(BohemkaDKP:GetBroadcastChannel(), self.EVENT.END_AUCTION_COUNTDOWN, self.currentItem.auctionId, BohemkaDKPConfig.timerMax)
        return
    end
    local _, itemLink = GetItemInfo(self.currentItem.id)
    if not self.currentItem.winner then
        SendChatMessage(format("Auction was cancelled."), BohemkaDKP:GetBroadcastChannel())
    else
        local currentDKP = self:GetCurrentDKP(self.currentItem.winner.name)
        local index = self.rosterIndex[self.currentItem.winner.name]
        self:SaveDKP(index, currentDKP - self.currentItem.winner.bid)
        SendChatMessage(format("%s awarded to %s for %d DKP.", itemLink, strsplit("-", self.currentItem.winner.name), self.currentItem.winner.bid), BohemkaDKP:GetBroadcastChannel())
    end


    local winner = self.currentItem.winner or {}
    self:SendEvent(
            BohemkaDKP:GetBroadcastChannel(),
            self.EVENT.END_AUCTION,
            self.currentItem.auctionId,
            winner.name, winner.bid
    )
    ActionButton_HideOverlayGlow(self.lastItemFrame);
end

function BohemkaDKP:OnEndAuction(auctionId, _, _)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self.currentItem = nil
    self.bidInfo = {}
    self.bidHistory = {}
    self.passedHistory = {}
    self.conflicts = {}
    BohemkaDKP:UpdateBidderTable()
    self.frames.auction.lootMasterFrame:Hide()
    self.frames.auction:Hide()
end

function BohemkaDKP:CancelAuctionCountdown()
    BohemkaDKP:SendEvent(BohemkaDKP:GetBroadcastChannel(), BohemkaDKP.EVENT.END_AUCTION_COUNTDOWN_CANCEL, BohemkaDKP.currentItem.auctionId)
    BohemkaDKP.countdownActive = false
    BohemkaDKP:UpdateWinner()
end

function BohemkaDKP:OnDelayedAuctionEnd(delay)
    self.frames.auction.statusBar.parent:Show()
    self.frames.auction.statusBar:SetMinMaxValues(0, delay)
    self.frames.auction.statusBar:SetValue(delay)
    local max = delay
    self.frames.auction.statusBar:SetScript("OnUpdate", function(self, elapsed)
        if delay > 0 and not BohemkaDKP.cancelCountdown then
            delay = delay - elapsed
            self:SetValue(delay)
            self.font:SetText(math.floor(delay+0.5))
            local color = BohemkaDKP:GetTimerColor(delay, max)
            if color then
                self:SetStatusBarColor(color.r, color.g, color.b)
            end
        else
            self:SetScript("OnUpdate", nil)
            self.parent:Hide()
            BohemkaDKP.cancelCountdown = false
            if delay <= 0 then
                BohemkaDKP:EndAuction(true)
                BohemkaDKP.countdownActive = false
            end
        end
    end)
end

function BohemkaDKP:OnEndAuctionCountdown(auctionId, countdown)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self:OnDelayedAuctionEnd(tonumber(countdown))
end

function BohemkaDKP:OnEndAuctionCountdownCancel(auctionId)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    self.cancelCountdown = true
end

function BohemkaDKP:GetItemMinPrice(itemName)
    return BohemkaDKPConfig.itemPrices[itemName] or BohemkaDKPConfig.minItemPrice
end


function BohemkaDKP:SendEvent(channel, event, ...)
    -- BohemkaDKP:Debug("Sending event", channel, event, ...)
    C_ChatInfo.SendAddonMessage(AddonName, self:PreparePayload(event, ...), channel)
end

function BohemkaDKP:SendEventTo(target, event, ...)
    -- BohemkaDKP:Debug("Sending event to", target, event, ...)
    C_ChatInfo.SendAddonMessage(AddonName, self:PreparePayload(event, ...), "WHISPER", target)
end

function BohemkaDKP:PreparePayload(event, ...)
    local payload = table.concat({...}, " ")
    if #payload > 0 then
        payload = format("%s %s", event, payload)
    else
        payload = event
    end
    return payload
end


function BohemkaDKP:IsPlayerAuctionOwner()
    return self.currentItem.owner == self:GetPlayerName(true)
end

function BohemkaDKP:GetCurrentDKP(fullName)
    return self.roster[fullName or self:GetPlayerName(true)]
end

function BohemkaDKP:EnableBidding(toggle)
    self.isBiddingEnabled = toggle
    if toggle then
        BohemkaDKP.frames.auction.bid:Enable()
    else
        BohemkaDKP.frames.auction.bid:Disable()
    end
end

function BohemkaDKP:SetHighestBidder(name, value)
    if name then
        local tooltip
        local nameStr
        if self.bidInfo.value == value then
            self.conflicts[name] = value
            self.conflicts[self.bidInfo.name] = self.bidInfo.value
            nameStr = self:colorize("Conflict", self.COLOR.DARKRED)
            local tmp =  {}
            for k, _ in pairs(self.conflicts) do
                table.insert(tmp, self:AddClassColorToName(k))
            end
            tooltip = table.concat(tmp, "\n")
        else
            nameStr = self:AddClassColorToName(name)
            self.conflicts = {}
        end
        self.frames.auction.highestBidder:SetText("Highest bid: "..nameStr)
        self.frames.auction.highestBidder:Show()
        self.frames.auction.highestBidder.frame.tooltip = tooltip
    else
        self.frames.auction.highestBidder:Hide()
    end
    self.bidInfo.value = value
    self.bidInfo.name = name
end


function BohemkaDKP:AddClassColorToName(name)
    local shortName = strsplit("-", name)
    if self.guildRoster[name] then
        local _, _, _, _, _, _, _, _, _, _, classFileName2  = unpack(self.guildRoster[name])
        classFileName = classFileName2
    else
        local _, classFileName2, _ = UnitClass(shortName)
        classFileName = classFileName2
    end
    if classFileName then
        local color = RAID_CLASS_COLORS[classFileName]
        local escapeColor = format("|cff%02x%02x%02x", color.r*255, color.g*255, color.b*255)
        shortName = escapeColor..shortName.."|r"
    end
    return shortName
end

function BohemkaDKP:SaveDKP(index, value, announceChannel)
    if not CanEditPublicNote() then
        return
    end
    if value == nil then
        GuildRosterSetPublicNote(index, "")
        return
    end
    value = string.format("%05d", value)
    GuildRosterSetPublicNote(index, value)
    if announceChannel then
        local fullName = GetGuildRosterInfo(index)
        SendChatMessage(format("%s's DKP changed to %d", strsplit("-", fullName), value), announceChannel)
    end
end

function BohemkaDKP:NoteDKPToNumber(note)
    local value =  tonumber(note:match("0*(%d+)"))
    if note:sub(1, 1) == "-" then
        value = value * -1
    end
    return value
end

function BohemkaDKP:ValidateBidderDKP()
    local updateHighestBidder = false
    for k, v in pairs(self.bidHistory) do
        if v > self:GetCurrentDKP(k) then
            self.bidHistory[k] = nil
            if self.bidInfo.name == k then
                updateHighestBidder = true
            end
        end
    end
    self:UpdateBidderTable()
    self:UpdateWinner()
    if updateHighestBidder then
        local winner = self.currentItem.winner or {}
        self:SendEvent(BohemkaDKP:GetBroadcastChannel(), self.EVENT.INVALIDATE_HIGHEST_BID, self.currentItem.auctionId, winner.name,  winner.bid)
    end
end

function BohemkaDKP:OnInvalidateHighestBid(auctionId, name, value, sender)
    if not self.currentItem or auctionId ~= self.currentItem.auctionId then
        self:Debug("Ignoring event. Auction has ended...")
        return
    end
    if not sender then
        sender = name
        name = nil
    end
    self:SetHighestBidder(name, tonumber(value))
    _G["AuctionItemPriceValue"]:SetText(value or self.currentItem.initPrice)
end

function BohemkaDKP:OnAuctionJoin(sender)
    if not self.currentItem or not self:IsPlayerAuctionOwner() then
        return
    end
    self:SendEventTo(sender, self.EVENT.AUCTION_JOIN_RESPONSE, table.toString(self.currentItem), table.toString(self.bidInfo))
end

function BohemkaDKP:OnAuctionJoinResponse(currentItem, bidInfo)
    currentItem = table.fromString(currentItem)
    bidInfo = table.fromString(bidInfo)
    self:OnStartAuction(currentItem.owner, currentItem.id, currentItem.quantity, currentItem.price, currentItem.auctionId, currentItem.minBid)
    if bidInfo.value then
        self:OnBid(bidInfo.value, bidInfo.name, currentItem.auctionId)

    end
    self:UpdateBidButtonState()
end

function BohemkaDKP:JoinExistingAuction()
    self:SendEvent(BohemkaDKP:GetBroadcastChannel(), self.EVENT.AUCTION_JOIN)
end

function BohemkaDKP:RequestProfessionInfo()
    self:SendEvent("GUILD", self.EVENT.PROFESSION_INFO_REQUEST)
end


function BohemkaDKP:RequestTalentsInfo()
    self:SendEvent("GUILD", self.EVENT.TALENTS_INFO_REQUEST)
end

function BohemkaDKP:OnProfessionInfoRequest(sender)
    if sender == self:GetPlayerName(true) then
        return
    end
    self:ShareProfessions()
end

function BohemkaDKP:OnTalentsInfoRequest(sender)
    if sender == self:GetPlayerName(true) then
        return
    end
    self:ShareTalents()
end

function BohemkaDKP:AddDKPSelected(value)
    for name, state in pairs(BohemkaDKP.editModeSelected) do
        if state then
            local i = self.rosterIndex[name]
            local currentValue = BohemkaDKP:NoteDKPToNumber(select(7, GetGuildRosterInfo(i)))
            BohemkaDKP:SaveDKP(i, currentValue + value)
        end
    end
end
function BohemkaDKP:SubtractDKPSelected(value)
    for name, state in pairs(BohemkaDKP.editModeSelected) do
        if state then
            local i = self.rosterIndex[name]
            local currentValue = BohemkaDKP:NoteDKPToNumber(select(7, GetGuildRosterInfo(i)))
            BohemkaDKP:SaveDKP(i, currentValue - value)
        end
    end
end

function BohemkaDKP:AwardDKPRaid(value, reason)
    local members = GetNumGroupMembers();
    local realmName = GetRealmName()
    for i = 1, members do
        local name = GetRaidRosterInfo(i)
        name, realm = UnitFullName(name)
        if not realm or #realm <= 0 then
            realm = realmName
        end
        local fullName = name.."-"..realm
        local guildIndex = self.rosterIndex[fullName]
        local newValue = self:GetCurrentDKP(fullName) + value
        self:SaveDKP(guildIndex, newValue)
    end
    if reason then
        SendChatMessage(format("Raid received %d DKP for %s.", value, reason), "RAID")
    else
        SendChatMessage(format("Raid received %d DKP.", value), "RAID")
    end

end

function BohemkaDKP:GetBroadcastChannel()
    if IsInRaid() then
        return "RAID"
    end
    if IsInGroup() then
        return "PARTY"
    end
    return "GUILD"
end

function BohemkaDKP:GetPlayerProfessions(fullName)
    local tmp = {}
    if BohemkaDKP.rosterProfessions[fullName] then
        for _, v in ipairs(BohemkaDKP.rosterProfessions[fullName]) do
            local spellId, spellRank = strsplit("-", v)
            spellId = tonumber(spellId)
            local name, _, icon = GetSpellInfo(spellId)
            local order = BohemkaDKP.PROFESSIONS[name]
            table.insert(tmp, {name = name, order = order, id = spellId, icon = icon, rank = spellRank})
        end
        table.sort(tmp, function (a, b) return a.order < b.order end)
    end
    return tmp
end

function BohemkaDKP:GetPlayerTalents(fullName)
    local tmp = {}
    if self.rosterTalents[fullName] then
        local class = select(11, unpack(self.guildRoster[fullName]))
        for _, v in ipairs(self.rosterTalents[fullName]) do
            local name, numTalents = strsplit("-", v)
            local icon = self.TALENTS[class][name]
            table.insert(tmp, {name = name, icon = icon, amount = numTalents})
        end
    end
    return tmp
end
